==> tcpstat-1.0.tar.gz: tcpstat-1.0/src/dump.c <==
/*
 * Copyright (c) 2000 Paul Herman
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/**********************************************************
 * Example of how to use the library included
 * with this program
 **********************************************************/
#include "tcpprof.h"

/* GLOBALS */
char filterexpr[BUF_SIZ]	= "";
int	get_tcp_flags		= 0;

void my_hook(packet_data *pd, void **args) { print_packet(pd); }

/*
 * process_file() takes the output of tcpdump, saves packets, and displays
 * statistics
 */
void process_file(char *fname, u_int unused) {
        get_tcpdump_data(fname, filterexpr, get_tcp_flags,
		-1.0, my_hook, NULL);
}

#define USAGE 							\
"Usage: %s [-?he] [-f filter expr] filename
	-?, -h 		- display this help
	-f filter expr 	- filter expression to pass to tcpdump
	-e		- include ethernet header in packet size
			  calculations when applicable (wire packet size)
"

int Usage(int r, char *prog) {
	fprintf(stderr, USAGE, my_basename(prog)); return r;
}

void error(char *s) {
	fprintf(stderr, "error: %s\n", s);
	Usage(-1, "tcpstat"); exit(-1);
}

int main(int argc, char **argv) {
	char ch, *filename;

	while ( (ch = getopt(argc, argv, "h?ef:")) != -1) {
		switch(ch) {
			case 'h':
			case '?':
				return Usage(1, argv[0]);
				break;
			case 'e':
				get_tcp_flags |= GET_TCPD_COUNT_ETHERSIZE;
				break;
			case 'f':
				strncpy(filterexpr, optarg, BUF_SIZ);
				break;
			default:
				break;
			}				
		}

	if ((argc - optind) < 1) error("must specify filename");

	filename = argv[optind];
	process_file(filename, 0);

	return 0;
}

==> tcpstat-1.2.tar.gz: tcpstat-1.2/src/dump.c <==
/*
 * Copyright (c) 2000 Paul Herman
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/**********************************************************
 * Example of how to use the library included
 * with this program
 **********************************************************/
#include "tcpstat.h"

/* GLOBALS */
char filterexpr[BUF_SIZ]	= "";
int	get_tcp_flags		= 0;

void my_hook(packet_data *pd, void **args) { print_packet(pd); }

/*
 * process_file() takes the output of tcpdump, saves packets, and displays
 * statistics
 */
void process_file(char *fname, u_int unused) {
        get_tcpdump_data(fname, filterexpr, get_tcp_flags,
		-1.0, my_hook, NULL);
}

#define USAGE 							\
"Usage: %s [-?he] [-f filter expr] filename
	-?, -h 		- display this help
	-f filter expr 	- filter expression to pass to tcpdump
	-e		- include ethernet header in packet size
			  calculations when applicable (wire packet size)
"

int Usage(int r, char *prog) {
	fprintf(stderr, USAGE, my_basename(prog)); return r;
}

void error(char *s) {
	fprintf(stderr, "error: %s\n", s);
	Usage(-1, "tcpstat"); exit(-1);
}

int main(int argc, char **argv) {
	char ch, *filename;

	while ( (ch = getopt(argc, argv, "h?ef:")) != -1) {
		switch(ch) {
			case 'h':
			case '?':
				return Usage(1, argv[0]);
				break;
			case 'e':
				get_tcp_flags |= GET_TCPD_COUNT_LINKSIZE;
				break;
			case 'f':
				strncpy(filterexpr, optarg, BUF_SIZ);
				break;
			default:
				break;
			}				
		}

	if ((argc - optind) < 1) error("must specify filename");

	filename = argv[optind];
	process_file(filename, 0);

	return 0;
}
